This module contains the Fork struct which is used to store the data
that will be loaded into an [Environment] and be used in arbiter-core.
Fork contains a CacheDB and ContractMetadata so
that the [Environment] can be initialized with a forked database and the
end-user still has access to the relevant metadata.
Structs
- Contract
Metadata - A
ContractMetadatais used to store the metadata of a contract that will be loaded into aFork. - Disk
Data - This is the data that will be written to and loaded from disk to generate a
Fork. - Fork
- A
Forkis used to store the data that will be loaded into an [Environment] and be used inarbiter-core. It is a wrapper around aCacheDBand aHashMapofContractMetadataso that theenvironment::Environmentcan be initialized with the data and the end-user still has access to the relevant metadata.