Module inspector

Module inspector 

This module contains an extensible Inspector called ArbiterInspector. It is currently configurable in order to allow for users to set configuration to see logs generated in Solidity contracts and or enforce gas payment.

Structs

ArbiterInspector
An configurable Inspector that collects information about the execution of the Interpreter. Depending on whether which or both features are enabled, it collects information about the gas used by each opcode and the console2.logs emitted during execution. It ensures gas payments are made when gas is enabled.