pub struct Logger { /* private fields */ }Expand description
EventLogger is a struct that logs events from the Ethereum network.
It contains a BTreeMap of events, where each event is represented by a
string key and a vector of Event instances. It also optionally contains a
path where the event logs will be stored.
Type Parameters
M- Middleware that implements theMiddlewaretrait,std::borrow::Borrow<D>, and has a static lifetime.D- Middleware that implements theMiddlewaretrait,Debug,Send,Sync, and has a static lifetime.E- Type that implements theEthLogDecode,Debug,Serializetraits, and has a static lifetime.
Implementations
Sourceimpl Logger
impl Logger
Sourcepub fn builder() -> Self
pub fn builder() -> Self
Constructs a new EventLogger.
Returns
A fresh EventLogger instance with an uninitialized events BTreeMap and
no specified path.
Sourcepub fn with_event<S: Into<String>, D: EthLogDecode + Debug + Serialize + 'static>(
self,
event: Event<Arc<ArbiterMiddleware>, ArbiterMiddleware, D>,
name: S,
) -> Self
pub fn with_event<S: Into<String>, D: EthLogDecode + Debug + Serialize + 'static>( self, event: Event<Arc<ArbiterMiddleware>, ArbiterMiddleware, D>, name: S, ) -> Self
Sourcepub fn file_type(self, file_type: OutputFileType) -> Self
pub fn file_type(self, file_type: OutputFileType) -> Self
Sourcepub fn run(self) -> Result<JoinHandle<()>, ArbiterCoreError>
pub fn run(self) -> Result<JoinHandle<()>, ArbiterCoreError>
Executes the EventLogger.
This function starts the event logging process. It first deletes the existing events directory, then creates a new directory for each event. For each event, it creates a new CSV file and writes the event data into the file. If the file already exists, it appends the new data to the file.
Returns
A Result which is:
Ok(())if theEventLoggerran successfully.Err(RevmMiddlewareError)if there was an error running theEventLogger.
Errors
This function will return an error if there is a problem creating the directories or files, or writing to the files.