Module fork

Module fork 

This module contains the Fork struct which is used to store the data that will be loaded into an [Environment] and be used in arbiter-core. Fork contains a CacheDB and ContractMetadata so that the [Environment] can be initialized with a forked database and the end-user still has access to the relevant metadata.

Structs

ContractMetadata
A ContractMetadata is used to store the metadata of a contract that will be loaded into a Fork.
DiskData
This is the data that will be written to and loaded from disk to generate a Fork.
Fork
A Fork is used to store the data that will be loaded into an [Environment] and be used in arbiter-core. It is a wrapper around a CacheDB and a HashMap of ContractMetadata so that the environment::Environment can be initialized with the data and the end-user still has access to the relevant metadata.