pub struct EnvironmentBuilder { /* private fields */ }Expand description
A builder for creating an Environment.
This builder allows for the configuration of an Environment before it is
instantiated. It provides methods for setting the label, gas limit, contract
size limit, and a database for the Environment.
Implementations
Sourceimpl EnvironmentBuilder
impl EnvironmentBuilder
Sourcepub fn build(self) -> Environment
pub fn build(self) -> Environment
Builds and runs an Environment with the parameters set in the
EnvironmentBuilder.
Sourcepub fn with_label(self, label: impl Into<String>) -> Self
pub fn with_label(self, label: impl Into<String>) -> Self
Sets the label for the Environment.
Sourcepub fn with_gas_limit(self, gas_limit: U256) -> Self
pub fn with_gas_limit(self, gas_limit: U256) -> Self
Sets the gas limit for the Environment.
Sourcepub fn with_contract_size_limit(self, contract_size_limit: usize) -> Self
pub fn with_contract_size_limit(self, contract_size_limit: usize) -> Self
Sets the contract size limit for the Environment.
Sourcepub fn with_state(self, state: impl Into<CacheDB<EmptyDB>>) -> Self
pub fn with_state(self, state: impl Into<CacheDB<EmptyDB>>) -> Self
Sets the state for the Environment. This can come from a saved state
of a simulation or a database::fork::Fork.
Sourcepub fn with_logs(self, logs: impl Into<HashMap<U256, Vec<eLog>>>) -> Self
pub fn with_logs(self, logs: impl Into<HashMap<U256, Vec<eLog>>>) -> Self
Sets the logs for the Environment. This can come from a saved state
of a simulation and can be useful for doing analysis.
Sourcepub fn with_arbiter_db(self, db: ArbiterDB) -> Self
pub fn with_arbiter_db(self, db: ArbiterDB) -> Self
Sets the entire database for the Environment including both the
state and logs. This can come from the saved state of a simulation and
can be useful for doing analysis.
Sourcepub fn with_console_logs(self) -> Self
pub fn with_console_logs(self) -> Self
Enables inner contract logs to be printed to the console as trace
level logs prepended with “Console logs: “.
Sourcepub fn with_pay_gas(self) -> Self
pub fn with_pay_gas(self) -> Self
Turns on gas payments for transactions so that the [EVM] will
automatically pay for gas and revert if balance is not met by sender.