The middleware module provides functionality to interact with
Ethereum-like virtual machines. It achieves this by offering a middleware
implementation for sending and reading transactions, as well as watching
for events.
Main components:
ArbiterMiddleware: The core middleware implementation.Connection: Handles communication with the Ethereum VM.- [
FilterReceiver]: Facilitates event watching based on certain filters.
Modules
- connection
- Messengers/connections to the underlying EVM in the environment.
- nonce_
middleware - The
nonce_middlewaremodule provides a middleware implementation for managing nonces for Ethereum-like virtual machines. A nonce is a number that is used only once in a cryptographic communication. In this case, it is used to ensure that each transaction sent from the address associated with the middleware is unique and cannot be replayed.
Structs
- Arbiter
Middleware - A middleware structure that integrates with
revm.
Enums
- EOA
- A wrapper enum for the two types of accounts that can be used with the middleware.
- Pending
TxState
Functions
- recast_
address - Recast a B160 into an Address type